package FormValidator::Lite::Messages::en;
use strict;
use warnings;
use utf8;

# TODO: we need english message profile
our $MESSAGES = {
    not_null => 'please input [_1]',
    int      => 'please input [_1] as integer',
    http_url => 'please input [_1] as url',
};

1;
__END__

=head1 NAME

FormValidator::Lite::Messages::ja - English language resource

